@@ -221,6 +221,8 @@ class Worker:
             client = boto3.client("sqs", config=config)
             self._sqs_clients[region] = client
 
+            logger.info(f"new sqs client {region} created")
+
         return client
 
     async def __aenter__(self):
@@ -393,6 +395,35 @@ class Worker:
         else:
             asyncio.ensure_future(coro)
 
+    async def receive_sqs_message(self, num_message=1):
+        queue_url = self._sqs_opts[OPTS_SQS_QUEUE_URL]
+        client = self.sqs_client(queue_url)
+
+        return await asyncio.get_running_loop().run_in_executor(
+            None,
+            partial(
+                client.receive_message,
+                QueueUrl=queue_url,
+                MaxNumberOfMessages=num_message,
+                WaitTimeSeconds=15,
+            ),
+        )
+
+    async def delete_sqs_message(self, receipt_handle):
+        queue_url = self._sqs_opts[OPTS_SQS_QUEUE_URL]
+        client = self.sqs_client(queue_url)
+
+        return await asyncio.get_running_loop().run_in_executor(
+            None,
+            partial(
+                client.delete_message, QueueUrl=queue_url, ReceiptHandle=receipt_handle,
+            ),
+        )
+
+    async def receive_redis_queue(self):
+        queue_key = self._redis_opts[OPTS_REDIS_QUEUE_KEY]
+        return await self._redis.blpop(queue_key)
+
     async def send_result(
         self, result, context=None, result_channel=None, wait_for_sqs=True
     ):
@@ -439,16 +470,22 @@ class Worker:
 
                 if context.get(CONTEXT_REDIS_QUEUE):
                     redis_queue = context.get(CONTEXT_REDIS_QUEUE)
-                    await self._redis.publish(redis_queue, result_data)
+                    await self._redis.rpush(redis_queue, result_data)
 
                     logger.info(
                         "pushing result with code {} "
-                        'to redis "{}"'.format(result.get("code", None), redis_queue)
+                        'to redis queue "{}"'.format(
+                            result.get("code", None), redis_queue
+                        )
                     )
 
             if context.get(CONTEXT_SQS_URL):
-                await self.send_sqs_message(
-                    context.get(CONTEXT_SQS_URL), result_data, wait=wait_for_sqs
+                sqs_queue = context.get(CONTEXT_SQS_URL)
+                await self.send_sqs_message(sqs_queue, result_data, wait=wait_for_sqs)
+
+                logger.info(
+                    "pushing result with code {} "
+                    'to sqs "{}"'.format(result.get("code", None), sqs_queue)
                 )
 
         # always check the result_channel as it is usually used for data persistence
